@@ -6,7 +6,7 @@ use warnings;
 
 use base qw(Linux::Distribution);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my %commands = (
     'debian'                => 'dpkg',
@@ -14,6 +14,7 @@ my %commands = (
     'redhat'                => 'rpm',
     'suse'                  => 'rpm',
     'gentoo'                => 'equery',
+    'slackware'             => 'pkgtool',
 );
 
 our @EXPORT_OK = qw(distribution_packages distribution_write format);
@@ -75,7 +76,7 @@ sub format {
 
 sub _retrieve_all {
     my $self = shift;
-    $self->{'command'} = $self->_command();
+    $self->_command();
     $self->{'_data'} = ` $self->{'command'} `;
     die "Error $? running \'$self->{'command'}\'\n" if $?;
 }
@@ -144,6 +145,14 @@ sub _close_output_fh {
         delete $self->{'output_file_handle'};
     }
 }
+
+sub _command {
+    my ( $self, $command ) = @_;
+    # Add options not really yet implemented
+    if ($self->{'options'}){ $command .= ' ' . $self->{'options'}; }
+    $self->{'command'} = $command;
+}
+
 return 1;
 
 package Linux::Distribution::Packages::equery;
@@ -151,9 +160,7 @@ use base qw(Linux::Distribution::Packages);
 
 sub _command {
     my $self = shift;
-    my $command = 'equery list';
-    if ($self->{'options'}){ $command .= ' ' . $self->{'options'}; }
-    return $command;
+    $self->SUPER::_command('equery list');
 }
 
 sub _parse {
@@ -180,10 +187,8 @@ package Linux::Distribution::Packages::dpkg;
 use base qw(Linux::Distribution::Packages);
 
 sub _command {
-    my $command = 'dpkg --list';
     my $self = shift;
-    if ($self->{'options'}){ $command .= ' ' . $self->{'options'}; }
-    return $command;
+    $self->SUPER::_command('dpkg --list');
 }
 
 sub _parse {
@@ -207,10 +212,8 @@ package Linux::Distribution::Packages::rpm;
 use base qw(Linux::Distribution::Packages);
 
 sub _command {
-    my $command = 'rpm -qa';
     my $self = shift;
-    if ($self->{'options'}){ $command .= ' ' . $self->{'options'}; }
-    return $command;
+    $self->SUPER::_command('rpm -qa');
 }
 
 sub _parse {
@@ -227,7 +230,28 @@ sub _parse {
     }
 }
 
+package Linux::Distribution::Packages::pkgtool;
+use base qw(Linux::Distribution::Packages);
+
+sub _command {
+    my $self = shift;
+    $self->SUPER::_command('ls /var/log/packages');
+}
+
+sub _parse {
+    my $self = shift;
+    my @data = split '\n', $self->{_data};
+    my $writer=shift;
+    foreach my $row (@data){
+        my ($pkg, $ver);
+        ($pkg, $ver) = $row =~ m/^(.+)\-(.+)\-.+\-\d+$/;
+        if ($self->{'format'} =~ m/xml/i){ $writer->emptyTag('package', 'name' => $pkg, 'version' => $ver ); next; }
+        my $row_func='_row_' . $self->{'format'};
+        $self->$row_func('', $pkg, $ver, '');
+    }
+}
 return 1;
+
 __END__
 
 
@@ -253,7 +277,10 @@ Linux::Distribution::Packages - list all packages on various Linux distributions
 This is a simple module that uses Linux::Distribution to guess the linux 
 distribution and then uses the correct commands to list all the packages 
 on the system and then output them in one of three formats:  native, csv, 
-and xml. 
+and xml.
+
+Distributions currently working:  debian, ubuntu, redhat, suse, gentoo, 
+slackware.
 
 The module inherits from Linux::Distribution, so can also use its calls.
 
@@ -270,6 +297,7 @@ Then write the formatted data from the hash.
 =head1 AUTHORS
 
 Judith Lebzelter, E<lt>judith@osdl.orgE<gt>
+Alberto Re, E<lt>alberto@accidia.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
